import 'package:comunic/forez/helpers/forez_group_helper.dart';
import 'package:comunic/helpers/groups_helper.dart';
import 'package:comunic/helpers/users_helper.dart';
import 'package:comunic/lists/group_members_list.dart';
import 'package:comunic/lists/users_list.dart';
import 'package:comunic/models/group_membership.dart';
import 'package:comunic/models/user.dart';
import 'package:comunic/ui/widgets/account_image_widget.dart';
import 'package:comunic/ui/widgets/async_screen_widget.dart';
import 'package:comunic/utils/intl_utils.dart';
import 'package:flutter/material.dart';

/// Forez directory screen
///
/// @author Pierre Hubert

class ForezDirectoryScreen extends StatefulWidget {
  @override
  _ForezDirectoryScreenState createState() => _ForezDirectoryScreenState();
}

class _ForezDirectoryScreenState extends State<ForezDirectoryScreen> {
  final _key = GlobalKey<AsyncScreenWidgetState>();

  UsersList _users;
  GroupMembersList _members;

  Future<void> _load() async {
    _members = await GroupsHelper.getMembersList(forezGroup.id);
    _users = await UsersHelper().getListWithThrow(_members.usersID);
  }

  @override
  Widget build(BuildContext context) => AsyncScreenWidget(
        onReload: _load,
        onBuild: onBuild,
        errorMessage: tr("Failed to load members list!"),
        key: _key,
      );

  Widget onBuild() => ListView.builder(
        itemBuilder: (c, i) =>
            _buildMember(_members[i], _users.getUser(_members[i].userID)),
        itemCount: _members.length,
      );

  Widget _buildMember(GroupMembership membership, User user) => ListTile(
        leading: AccountImageWidget(user: user),
        title: Text(user.fullName),
        subtitle: Text(membership.membershipText),
      );
}
